ConflictId

Type Alias ConflictId 

pub type ConflictId = SigId;
Stable id for a conflict within a session. We use the SigId as the conflict id since conflicts are 1:1 with the sigs that have MergeOutcome::Conflict. If a future merge ever produces multiple conflicts on the same sig, this becomes a tuple.

Aliased Type

pub struct ConflictId { /* private fields */ }