evaluate

Function evaluate 

pub fn evaluate(
    op_log: &OpLog,
    predicate: &Predicate,
) -> Result<Vec<OperationRecord>>
Evaluate a predicate against an op log. Session clauses are resolved as if no intent had a session — most callers go through evaluate_with_resolver instead. Use this entry point when the predicate is known not to reference sessions.