pub type ContentHash = String;Expand description
Content hash of a file (examples list, body source, etc.). Kept
as a string for the same reason as OpId: we want this crate
to have no view into the hash function used by callers.
Aliased Type
pub struct ContentHash { /* private fields */ }